@@ -1,4 +1,4 @@
-version = (0, 9, 5)
+version = (0, 9, 7)
 
 
 def register(cls, **kwargs):
@@ -30,17 +30,18 @@ def autodiscover():
     import copy
     from django.conf import settings
     from django.utils.importlib import import_module
+    from basky.config import BasketRegistry
 
     for app in settings.INSTALLED_APPS:
         try:
-            mod = import_module(app)
+            import_module(app)
         except ImportError:
             pass
         # Attempt to import the app's basket module.
         try:
             before_import_registry = copy.copy(BasketRegistry._registry)
-            b = import_module('%s.basket' % app)
+            import_module('%s.basket' % app)
         except ImportError:
             pass
-        except Exception, e:
+        except Exception:
             BasketRegistry._registry = before_import_registry
